@@ -7,6 +7,7 @@ import sys
 import sys,os
 sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 
+
 import dbpystream.api as db
 
 def test_get_price():
@@ -22,6 +23,7 @@ def test_get_price():
     t0 = t.time()
 
     df  = db.get_price(codes,start_date,end_date,frequency,fq) ## data为返回的是pd.dataframe格式的数据；
+    df.to_csv(r"C:\Users\songroom\Desktop\df.csv")
     print(f"code : {codes} df shape : {df.shape} ")
     print(f"-------------{fq}--------------------")
     print(f"{df.head()}")
@@ -61,7 +63,7 @@ def test_get_trade_days():
     print(f"get_trade_days : {df}")
 
 if __name__== "__main__" :
-    db.auth("176*********","6********") # 可以明文输入，可也以在环境变量中设置
+    db.auth() # 
     test_get_all_securities()
     test_get_index_weights()
     test_get_industry_stocks()
